@@ -4,6 +4,20 @@ use time::macros::format_description;
 #[derive(Parser)]
 #[clap(name = "wordle", author, version)]
 pub struct App {
+    #[clap(long)]
+    #[cfg(feature = "tui")]
+    /// Disables the TUI
+    ///
+    /// This disables the TUI and any enriched experience
+    pub no_tui: bool,
+
+    #[clap(long)]
+    /// Enables hard mode
+    ///
+    /// Hard mode adds the restriction that you must only make
+    /// guesses including the all exact matches you have found
+    pub hard: bool,
+
     #[clap(subcommand)]
     pub game_mode: Option<GameMode>,
 }
@@ -16,6 +30,7 @@ pub enum GameMode {
     Day(Day),
     /// Play the specified date's wordle
     Date(Date),
+    #[cfg(feature = "rand")]
     /// Play a random day
     Random,
 }
