@@ -1,30 +1,40 @@
+use cl_wordle::game::Game;
 use clap::Parser;
 
 mod args;
 mod controller;
-mod game;
-mod guess;
-mod keyboard;
-mod letters;
-mod terminal;
 
 use args::{App, GameMode};
-use controller::GameController;
-use game::Game;
+use controller::cli;
+
+#[cfg(feature = "rand")]
 use rand::Rng;
 
 fn main() -> eyre::Result<()> {
     let app = App::parse();
-    let game = match app.game_mode {
+    let mut game = match app.game_mode {
         None => Game::new()?,
         Some(GameMode::Custom(custom)) => Game::custom(custom.word)?,
         Some(GameMode::Day(day)) => Game::from_day(day.day)?,
+        #[cfg(feature = "rand")]
         Some(GameMode::Random) => Game::from_day(rand::thread_rng().gen())?,
         Some(GameMode::Date(date)) => Game::from_date(date.date)?,
     };
 
-    let controller = GameController::new(game)?;
-    if let Some(share) = controller.run()? {
+    if app.hard {
+        game.hard_mode();
+    }
+
+    #[cfg(feature = "tui")]
+    let output = if app.no_tui {
+        Some(cli::Controller::new(game).run()?)
+    } else {
+        controller::tui::Controller::new(game)?.run()?
+    };
+    #[cfg(not(feature = "tui"))]
+    let output = Some(cli::Controller::new(game).run()?);
+
+    if let Some(share) = output {
         println!("{}", share);
     }
 
