@@ -1,7 +1,9 @@
-use std::fmt::Display;
+use std::{fmt::Display, ops::Deref};
 
 pub mod words;
 pub mod state;
+pub mod game;
+pub mod iter;
 
 /// Gets the solution word for the given day
 pub fn get_solution(day: usize) -> &'static str {
@@ -52,6 +54,14 @@ impl Display for Matches {
     }
 }
 
+impl Deref for Matches {
+    type Target = [Match; 5];
+
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+
 pub fn diff(input: &str, solution: &str) -> Matches {
     assert!(
         input.is_ascii(),
